// $Id$
/**
* Copyright (C) 2015 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.molecular.handler;


import info.bioinfweb.libralign.alignmentarea.AlignmentArea;
import info.bioinfweb.libralign.dataarea.implementations.pherogram.PherogramArea;
import info.bioinfweb.libralign.pherogram.PherogramComponent;

import java.util.Iterator;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.ui.IWorkbenchPart;

import eu.etaxonomy.taxeditor.model.AbstractUtility;
import eu.etaxonomy.taxeditor.molecular.editor.AlignmentEditor;
import eu.etaxonomy.taxeditor.molecular.editor.PherogramViewPart;



/**
 * Abstract handler implementation allows to performs the concrete operation either on an instance of
 * {@link PherogramViewPart} or all {@link AlignmentArea}s inside an instance of {@link AlignmentEditor}.
 *
 * @author Ben Stöver
 * @date 23.06.2015
 */
public abstract class AbstractPherogramComponentHandler extends AbstractHandler {
    @Override
    public Object execute(ExecutionEvent event) throws ExecutionException {
        IWorkbenchPart activePart = AbstractUtility.getActivePart();

        if (activePart instanceof AlignmentEditor) {
            AlignmentEditor editor = (AlignmentEditor)activePart;
            Iterator<Integer> idIterator = editor.getReadsArea().getAlignmentModel().sequenceIDIterator();
            while (idIterator.hasNext()) {
                PherogramArea area = editor.getPherogramArea(idIterator.next());
                if (area != null) {
                    doExecute(event, area);
                }
            }
        }
        else if (activePart instanceof PherogramViewPart) {
            doExecute(event, ((PherogramViewPart)activePart).getPherogramView().getTraceCurveView());
        }
        return null;
    }


    public abstract void doExecute(ExecutionEvent event, PherogramComponent component) throws ExecutionException;
}
